@@ -61,23 +61,25 @@ class MetaflowCodeContentV1(MetaflowCodeContentV1Base):
         else:
             new_modules = []
 
-        self._modules = {
-            name: _ModuleInfo(
-                name,
-                set(
-                    Path(p).resolve().as_posix()
-                    for p in getattr(mod, "__path__", [mod.__file__])
-                ),
-                mod,
-                True,  # This is a Metaflow module (see filter below)
-            )
-            for (name, mod) in new_modules
-        }
-
-        # Filter the modules
-        self._modules = {
-            name: info for name, info in self._modules.items() if criteria(info.module)
-        }
+        self._modules = {}  # type: Dict[str, _ModuleInfo]
+        # We do this explicitly module by module to harden it against misbehaving
+        # modules like the one in:
+        # https://github.com/Netflix/metaflow/issues/2512
+        # We will silently ignore modules that are not well built.
+        for name, mod in new_modules:
+            try:
+                minfo = _ModuleInfo(
+                    name,
+                    set(
+                        Path(p).resolve().as_posix()
+                        for p in getattr(mod, "__path__", [mod.__file__])
+                    ),
+                    mod,
+                    True,  # This is a Metaflow module (see filter below)
+                )
+            except:
+                continue
+            self._modules[name] = minfo
 
         # Contain metadata information regarding the distributions packaged.
         # This allows Metaflow to "fake" distribution information when packaged
@@ -355,16 +357,14 @@ class MetaflowCodeContentV1(MetaflowCodeContentV1Base):
                 )
                 yield json.dumps(self.create_mfcontent_info()).encode(
                     "utf-8"
-                ), os.path.join(self._code_dir, MFCONTENT_MARKER)
+                ), MFCONTENT_MARKER
             else:
                 for k in self._other_content.keys():
                     yield "<generated %s content>" % (os.path.basename(k)), k
                 yield "<generated %s content>" % (
                     os.path.basename(self._dist_info_file)
                 ), os.path.join(self._other_dir, self._dist_info_file)
-                yield "<generated %s content>" % MFCONTENT_MARKER, os.path.join(
-                    self._code_dir, MFCONTENT_MARKER
-                )
+                yield "<generated %s content>" % MFCONTENT_MARKER, MFCONTENT_MARKER
 
     def _metaflow_distribution_files(self) -> Generator[Tuple[str, str], None, None]:
         debug.package_exec("Including Metaflow from '%s'" % self._metaflow_root)
